@@ -7,6 +7,7 @@ AUTHOR="David Bagley"
 if test "$1" = "-p"; then
 	PROG=$NAME
 fi
+PROGZIP=$PROG.tar.bz2
 if test "$VERSION" = ""; then
 	echo "run from $NAME main directory"
 	exit
@@ -27,6 +28,13 @@ for i in $LIST; do
 		cp -rp $i $PROG
 	fi
 done	
-tar cvjf $PROG.tar.bz2 $PROG
+tar cvf - $PROG | bzip2 > $PROGZIP
 rm -rf $PROG
-mv $PROG.tar.bz2 ..
+mv $PROGZIP ..
+if test "$1" != "-p"; then
+	cd ..
+	gpg --print-md SHA1 $PROGZIP > $PROGZIP.sha
+	gpg --print-md MD5 $PROGZIP > $PROGZIP.md5
+	gpg --armor --output $PROGZIP.asc --detach-sig $PROGZIP
+	gpg --verify $PROGZIP.asc $PROGZIP
+fi
