@@ -650,6 +650,7 @@ listbox $LISTSCROL.list -yscroll  "$LISTSCROL.scroll set"
 #insert all modes in list
 #---------------------------
 $LISTSCROL.list  insert 0 \
+anemone\
 ant\
 ant3d\
 apollonian\
@@ -733,7 +734,9 @@ pipes\
 polyominoes\
 puzzle\
 pyro\
+pyro2\
 qix\
+rain\
 roll\
 rotor\
 rubik\
