@@ -198,7 +198,7 @@ typedef struct {
 	GC          stippledGC;
 	Pixmap      pixmaps[NUMSTIPPLES - 1];
 	int         labelOffsetX, labelOffsetY;
-	char        ruleString[40];
+	char        ruleString[50];
 	union {
 		XPoint      hexagon[7];		/* Need more than 6 for truchet */
 		XPoint      triangle[2][4];	/* Need more than 3 for truchet */
@@ -490,6 +490,8 @@ static void
 fillcell(ModeInfo * mi, GC gc, int col, int row)
 {
 	antfarmstruct *ap = &antfarms[MI_SCREEN(mi)];
+	Display *display = MI_DISPLAY(mi);
+	Window window = MI_WINDOW(mi);
 
 	if (ap->neighbors == 6) {
 		int         ccol = 2 * col + !(row & 1), crow = 2 * row;
@@ -502,13 +504,13 @@ fillcell(ModeInfo * mi, GC gc, int col, int row)
 			ap->shape.hexagon[0].x = ap->yb + crow * ap->ys;
 		}
 		if (ap->xs == 1 && ap->ys == 1)
-			XDrawPoint(MI_DISPLAY(mi), MI_WINDOW(mi), gc,
+			XDrawPoint(display, window, gc,
 			ap->shape.hexagon[0].x, ap->shape.hexagon[0].y);
 		else
-			XFillPolygon(MI_DISPLAY(mi), MI_WINDOW(mi), gc,
+			XFillPolygon(display, window, gc,
 			    ap->shape.hexagon, 6, Convex, CoordModePrevious);
 	} else if (ap->neighbors == 4 || ap->neighbors == 8) {
-		XFillRectangle(MI_DISPLAY(mi), MI_WINDOW(mi), gc,
+		XFillRectangle(display, window, gc,
 		ap->xb + ap->xs * col, ap->yb + ap->ys * row,
 	 	ap->xs - (ap->xs > 3), ap->ys - (ap->ys > 3));
 	} else {		/* TRI */
@@ -535,13 +537,17 @@ fillcell(ModeInfo * mi, GC gc, int col, int row)
 					(ap->xs / 2  - 1) * ((orient) ? 1 : -1);
 		}
 		if (small)
-			XDrawPoint(MI_DISPLAY(mi), MI_WINDOW(mi), gc,
+			XDrawPoint(display, window, gc,
 				ap->shape.triangle[orient][0].x,
 				ap->shape.triangle[orient][0].y);
 		else {
-			XFillPolygon(MI_DISPLAY(mi), MI_WINDOW(mi), gc,
+			XFillPolygon(display, window, gc,
 				ap->shape.triangle[orient], 3,
 				Convex, CoordModePrevious);
+			XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
+			XDrawLines(display, window, gc,
+				ap->shape.triangle[orient], 4,
+				CoordModePrevious);
 		}
 	}
 }
@@ -976,10 +982,10 @@ getTable(ModeInfo * mi, int i)
 	total = ap->ncolors * ap->nstates;
 	if (MI_IS_VERBOSE(mi))
 		(void) fprintf(stdout,
-			       "ants %d, neighbors %d, table number %d, colors %d, states %d\n",
-			  ap->n, ap->neighbors, i, ap->ncolors, ap->nstates);
+			"ants %d, neighbors %d, table number %d, colors %d, states %d\n",
+			ap->n, ap->neighbors, i, ap->ncolors, ap->nstates);
 	if (label)
-		(void) sprintf(ap->ruleString, "table number %d", i);
+		(void) sprintf(ap->ruleString, "%d table number %d", ap->n, i);
 	for (j = 0; j < total; j++) {
 		status = &(ap->machine[j]);
 		status->color = *patptr++;
@@ -1054,7 +1060,8 @@ getTurk(ModeInfo * mi, int logClass, int number)
 			"ants %d, neighbors %d, Turk's number 0x%x, colors %d\n",
 			ap->n, ap->neighbors, number, ap->ncolors);
 	if (label)
-		(void) sprintf(ap->ruleString, "Turk's number 0x%x", number);
+		(void) sprintf(ap->ruleString, "%d Turk's number 0x%x",
+			ap->n, number);
 }
 
 static void
@@ -1178,7 +1185,10 @@ init_ant(ModeInfo * mi)
 			free(ap->ants);
 			ap->ants = (antstruct *) NULL;
 		}
-		ap->n = NRAND(-ap->n - MINANTS + 1) + MINANTS;
+		/*ap->n = NRAND(-ap->n - MINANTS + 1) + MINANTS;*/
+		/* skew so that 1 is more likely */
+		ap->n = -ap->n - (int) (sqrt(NRAND(ap->n *ap->n - 1))) - 1 +
+			MINANTS;
 	} else if (ap->n < MINANTS)
 		ap->n = MINANTS;
 
@@ -1338,10 +1348,15 @@ init_ant(ModeInfo * mi)
 	ap->labelOffsetX = NRAND(8);
 	ap->labelOffsetY = NRAND(8);
 	parseRule(mi);
-	if (MI_NPIXELS(mi) > 2)
-		for (i = 0; i < (int) ap->ncolors - 1; i++)
-			ap->colors[i] = (unsigned char) (NRAND(MI_NPIXELS(mi)) +
-			     i * MI_NPIXELS(mi)) / ((int) (ap->ncolors - 1));
+	if (MI_NPIXELS(mi) > 2) {
+		int offset = NRAND(MI_NPIXELS(mi));
+
+		for (i = 0; i < (int) ap->ncolors - 1; i++) {
+			ap->colors[i] = (unsigned char) ((offset +
+				(i * MI_NPIXELS(mi) / (int) (ap->ncolors - 1))) %
+				MI_NPIXELS(mi));
+		}
+	}
 	if (ap->ants == NULL) {
 		if ((ap->ants = (antstruct *) malloc(ap->n * sizeof (antstruct))) ==
 				NULL) {
