@@ -177,7 +177,7 @@ typedef struct {
 	Pixmap      pixmaps[NCOLORS - 1];
 	int         nInvisible;
 	int         labelOffsetX, labelOffsetY;
-	char        ruleString[40];
+	char        ruleString[50];
 } antfarm3dstruct;
 
 /* Coordinate ant moves */
@@ -760,7 +760,7 @@ getTable(ModeInfo * mi, int i)
 			"ants %d, table number %d, colors %d, states %d\n",
 			ap->n, i, ap->ncolors, ap->nstates);
 	if (label)
-		(void) sprintf(ap->ruleString, "table number %d", i);
+		(void) sprintf(ap->ruleString, "%d table number %d", ap->n, i);
 	for (j = 0; j < total; j++) {
 		status = &(ap->machine[j]);
 		status->color = *patptr++;
@@ -797,7 +797,8 @@ getTurk(ModeInfo * mi, int logClass, int number)
 			"ants %d, Turk's number 0x%x, colors %d\n",
 			ap->n, number, ap->ncolors);
 	if (label)
-		(void) sprintf(ap->ruleString, "Turk's number 0x%x", number);
+		(void) sprintf(ap->ruleString, "%d Turk's number 0x%x",
+			ap->n, number);
 }
 
 static void
@@ -1388,7 +1389,10 @@ init_ant3d(ModeInfo * mi)
 			free(ap->ants);
 			ap->ants = NULL;
 		}
-		ap->n = NRAND(-ap->n - MINANTS + 1) + MINANTS;
+		/*ap->n = NRAND(-ap->n - MINANTS + 1) + MINANTS;*/
+		/* skew so that 1 is more likely */
+		ap->n = -ap->n - (int) (sqrt(NRAND(ap->n *ap->n - 1))) - 1 +
+			MINANTS;
 	} else if (ap->n < MINANTS)
 		ap->n = MINANTS;
 
@@ -1410,10 +1414,15 @@ init_ant3d(ModeInfo * mi)
 	ap->labelOffsetX = NRAND(8);
         ap->labelOffsetY = NRAND(8);
 	parseRule(mi);
-	if (MI_NPIXELS(mi) > 2)
-		for (i = 0; i < (int) ap->ncolors - 1; i++)
-			ap->colors[i] = (unsigned char) (NRAND(MI_NPIXELS(mi)) +
-				i * MI_NPIXELS(mi)) / ((int) (ap->ncolors - 1));
+	if (MI_NPIXELS(mi) > 2) {
+		int offset = NRAND(MI_NPIXELS(mi));
+
+		for (i = 0; i < (int) ap->ncolors - 1; i++) {
+			ap->colors[i] = (unsigned char) ((offset +
+				(i * MI_NPIXELS(mi) / (int) (ap->ncolors - 1))) %
+				MI_NPIXELS(mi));
+		}
+	}
 	if (ap->tape != NULL)
 		free(ap->tape);
 	if ((ap->tape = (unsigned char *) calloc(
