@@ -1314,8 +1314,11 @@ init_bug(ModeInfo * mi)
 			info.age = 0;
 			info.energy = INITENERGY;
 			info.direction = NRAND(bp->neighbors);
-			for (gene = 0; gene < bp->neighbors; gene++)
-#if 0
+			for (gene = 0; gene < bp->neighbors; gene++) {
+#if 1
+				/* Jitterbugs, evolve or die */
+				info.gene[gene] = 0;
+#else
 				/* Some creationalism, may create gliders or twirlers */
 				do {
 					double      temp = (double) LRAND() / MAXRAND;
@@ -1324,9 +1327,8 @@ init_bug(ModeInfo * mi)
 						((LRAND() & 1) ? -1 : 1);
 				} while (info.gene[gene] > MAXGENE / 2 ||
 					 info.gene[gene] < MINGENE / 2);
-#else /* Jitterbugs, evolve or die */
-				info.gene[gene] = 0;
 #endif
+			}
 			sum = 0;
 			for (gene = 0; gene < bp->neighbors; gene++)
 				sum += genexp[info.gene[gene] + MAXGENE];
@@ -1334,9 +1336,12 @@ init_bug(ModeInfo * mi)
 				info.gene_prob[gene] = genexp[info.gene[gene] + MAXGENE] / sum;
 #if EXTRA_GENES
 			if (bp->neighbors % 2) {
-				for (gene = 0; gene < bp->neighbors; gene++)
-#if 0
-				/* Some creationalism, may create gliders or twirlers */
+				for (gene = 0; gene < bp->neighbors; gene++) {
+#if 1
+					/* Jitterbugs, evolve or die */
+					info.lgene[gene] = 0;
+#else
+					/* Some creationalism, may create gliders or twirlers */
 					do {
 						double      temp = (double) LRAND() / MAXRAND;
 
@@ -1344,9 +1349,8 @@ init_bug(ModeInfo * mi)
 							((LRAND() & 1) ? -1 : 1);
 					} while (info.lgene[gene] > MAXGENE / 2 ||
 						 info.lgene[gene] < MINGENE / 2);
-#else /* Jitterbugs, evolve or die */
-					info.lgene[gene] = 0;
 #endif
+				}
 				sum = 0;
 				for (gene = 0; gene < bp->neighbors; gene++)
 					sum += genexp[info.lgene[gene] + MAXGENE];
