@@ -22,6 +22,8 @@ static const char sccsid[] = "@(#)dclock.c	5.00 2000/11/01 xlockmore";
  * other special, indirect and consequential damages.
  *
  * Revision History:
+ * 03-Dec-2005: Added a binary clock display, after seeing the binary clock
+ *              at thinkgeek. Petey (petey_leinonen@yahoo.com.au)
  * 01-Mar-2005: Added 24 hour clock (alex(at)shark-linux(dot)de)
  * 01-Nov-2000: Allocation checks
  * 07-May-1999: New "savers" added for y2k and second millennium countdowns.
@@ -136,6 +138,11 @@ static const char sccsid[] = "@(#)dclock.c	5.00 2000/11/01 xlockmore";
 #define LED_WIDTH (0.15 * LED_YS)
 #define LED_INC (LED_LEAN * LED_XS) /* LEAN and INC do not have to be linked */
 
+#define BINARY_WIDTH 10
+#define BINARY_HEIGHT 10
+#define BINARY_INC 5
+
+#define DEF_BINARY "False"
 #define DEF_LED    "False"
 #define DEF_POPEX  "False"
 #define DEF_FOREST "False"
@@ -150,9 +157,9 @@ static const char sccsid[] = "@(#)dclock.c	5.00 2000/11/01 xlockmore";
         a
         _
     f / / b
-      -g
+      - g
   e /_/ c
-    d
+     d
  */
 
 #define MAX_LEDS 7
@@ -197,6 +204,7 @@ static XPoint parallelogramUnit[4] =
 	{-2, 0}
 };
 
+static Bool binary;
 static Bool popex;
 static Bool forest;
 static Bool hiv;
@@ -208,6 +216,8 @@ static Bool millennium;
 
 static XrmOptionDescRec opts[] =
 {
+	{(char *) "-binary", (char *) ".dclock.binary", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+binary", (char *) ".dclock.binary", XrmoptionNoArg, (caddr_t) "off"},
 	{(char *) "-led", (char *) ".dclock.led", XrmoptionNoArg, (caddr_t) "on"},
 	{(char *) "+led", (char *) ".dclock.led", XrmoptionNoArg, (caddr_t) "off"},
 	{(char *) "-popex", (char *) ".dclock.popex", XrmoptionNoArg, (caddr_t) "on"},
@@ -229,6 +239,7 @@ static XrmOptionDescRec opts[] =
 };
 static argtype vars[] =
 {
+	{(void *) & binary, (char *) "binary", (char *) "Binary", (char *) DEF_BINARY, t_Bool},
 	{(void *) & led, (char *) "led", (char *) "LED", (char *) DEF_LED, t_Bool},
 	{(void *) & popex, (char *) "popex", (char *) "PopEx", (char *) DEF_POPEX, t_Bool},
 	{(void *) & forest, (char *) "forest", (char *) "Forest", (char *) DEF_FOREST, t_Bool},
@@ -241,6 +252,7 @@ static argtype vars[] =
 };
 static OptionStruct desc[] =
 {
+	{(char *) "-/+binary", (char *) "turn on/off binary clock display"},
 	{(char *) "-/+led", (char *) "turn on/off Light Emitting Diode seven segment display"},
 	{(char *) "-/+popex", (char *) "turn on/off population explosion counter"},
 	{(char *) "-/+forest", (char *) "turn on/off tropical forest destruction counter"},
@@ -256,7 +268,7 @@ ModeSpecOpt dclock_opts =
 {sizeof opts / sizeof opts[0], opts, sizeof vars / sizeof vars[0], vars, desc};
 
 #ifdef USE_MODULES
-ModStruct   dclock_description =
+ModStruct dclock_description =
 {"dclock", "init_dclock", "draw_dclock", "release_dclock",
  "refresh_dclock", "init_dclock", (char *) NULL, &dclock_opts,
  10000, 1, 10000, 1, 64, 0.3, "",
@@ -282,66 +294,87 @@ ModStruct   dclock_description =
 
 #ifdef USE_MB
 static XFontSet mode_font = None;
-static int font_height(XFontSet f)
+static int getFontHeight(XFontSet f)
 {
-  XRectangle ink, log;
-  if (f == None) {
-    return 8;
-  } else {
-      XmbTextExtents(mode_font, "My", strlen("My"), &ink, &log);
-      return log.height;
-  }
+	XRectangle ink, log;
+
+	if (f == None) {
+		return 8;
+	} else {
+		XmbTextExtents(mode_font, "My", strlen("My"), &ink, &log);
+		return log.height;
+	}
+}
+static int getTextWidth(char *string)
+{
+	XRectangle ink, logical;
+
+	XmbTextExtents(mode_font, string, strlen(string), &ink, &logical);
+	return logical.width;
 }
 #define DELTA 0.2
 extern XFontSet getFontSet(Display * display);
+#define DrawString(d, p, gc, start, ascent, string, len) (void) XmbDrawString(\
+	d, p, mode_font, gc, start, ascent, string, len)
 #else
 static XFontStruct *mode_font = None;
-#define font_height(f) (f->ascent + f->descent)
+#define getFontHeight(f) ((f == None) ? 8 : f->ascent + f->descent)
+static int getTextWidth(char *string)
+{
+	return XTextWidth(mode_font, string, strlen(string));
+}	
 #define DELTA 0
 extern XFontStruct *getFont(Display * display);
+#define DrawString(d, p, gc, start, ascent, string, len) (void) XDrawString(\
+	d, p, gc, start, ascent, string, len)
 #endif
 
-#ifdef USE_MB
-#define free_font(d) if (mode_font!=None){XFreeFontSet(d,mode_font); \
-mode_font = None;}
+#if 0
+#define MAXWIDTH BUFSIZ
 #else
-#define free_font(d) if (mode_font!=None){XFreeFont(d,mode_font); \
-mode_font = None;}
+#define MAXWIDTH 170
 #endif
-
+#if 0
 #define STRSIZE 50
+#define MAXLINES 2
+#else
+#define STRSIZE BUFSIZ
+#define MAXLINES 40
+#endif
 
 typedef struct {
 	int         color;
 	short       height, width;
-	char       *str, str1[STRSIZE], str2[STRSIZE], str1old[STRSIZE], str2old[STRSIZE];
-	char       *str1pta, *str2pta, *str1ptb, *str2ptb;
+	char       *str;
+	int         lines;
+	char        strnew[MAXLINES][STRSIZE], strold[MAXLINES][STRSIZE];
+	char       *strpta[MAXLINES], *strptb[MAXLINES];
+	short       textWidth[MAXLINES], textStart[MAXLINES];
 	time_t      timenew, timeold;
 	int         tzoffset;
 	short       maxx, maxy, clockx, clocky;
-	short       text_height, text_width, text_width1, text_width2;
-	short       text_start1, text_start2;
-	short       text_ascent, text_descent;
+	short       text_height, text_width, text_ascent, text_descent;
 	short       hour;
 	short       dx, dy;
-	int         done;
 	int         pixw, pixh;
 	Pixmap      pixmap;
 	GC          fgGC, bgGC;
-	Bool        popex, forest, hiv, lab, veg, time24, y2k, millennium, led;
+	Bool        popex, forest, hiv, lab, veg;
+	Bool        time24, y2k, millennium, led, binary;
 	XPoint      parallelogram[4];
 } dclockstruct;
 
 static dclockstruct *dclocks = (dclockstruct *) NULL;
 
+extern char *message;
 
 static unsigned long
 timeAtLastNewYear(long timeNow)
 {
-  struct tm *t;
+	struct tm *t;
 
-  t = localtime((const time_t *) &timeNow);
-  return (unsigned long)(t->tm_year);
+	t = localtime((const time_t *) &timeNow);
+	return (unsigned long)(t->tm_year);
 }
 
 #ifndef HAVE_SNPRINTF
@@ -359,9 +392,9 @@ convert(double x, char *string)
 	(void) snprintf(string, STRSIZE, "%'.0f", x);
 #else
 
-	int         i, j, k = 0;
-	int         place = (int) (log(x) / logbase);
-	double      divisor = 1.0;
+	int i, j, k = 0;
+	int place = (int) (log(x) / logbase);
+	double divisor = 1.0;
 
 	for (i = 0; i < place; i++)
 		divisor *= BASE;
@@ -394,32 +427,34 @@ dayhrminsec(long timeCount, int tzoffset, char *string)
 	/* snprintf would make this easier but its not always available */
 	bufsize = 16 + strlen((days==1) ? DAY : DAYS);
 	if (bufsize >= STRSIZE)
-          return;
+		return;
 	(void) sprintf(string, "%d %s", days, (days==1) ? DAY : DAYS);
 
 	i = strlen(string);
 	bufsize = 4 + strlen((hours==1) ? HOUR : HOURS);
 	if (i + bufsize >= STRSIZE)
-          return;
+		return;
 	(void) sprintf(&string[i], " %d %s", hours, (hours==1) ? HOUR : HOURS);
 
 	i = strlen(string);
 	bufsize = 4 + strlen((minutes==1) ? MINUTE : MINUTES);
 	if (i + bufsize >= STRSIZE)
-          return;
-	(void) sprintf(&string[i], " %d %s", minutes, (minutes==1) ? MINUTE : MINUTES);
+		return;
+	(void) sprintf(&string[i], " %d %s", minutes,
+		(minutes==1) ? MINUTE : MINUTES);
 
 	i = strlen(string);
 	bufsize += 4 + strlen((secs==1) ? SECOND : SECONDS);
 	if (i + bufsize >= STRSIZE)
-          return;
-	(void) sprintf(&string[i], " %d %s", secs, (secs==1) ? SECOND : SECONDS);
+		return;
+	(void) sprintf(&string[i], " %d %s", secs,
+		(secs==1) ? SECOND : SECONDS);
 
 	if (!tzoffset) {
 		i = strlen(string);
-		bufsize += 6;  /* strlen(" (UTC)"); */
-        	if (i + bufsize >= STRSIZE)
-          		return;
+		bufsize += 6; /* strlen(" (UTC)"); */
+		if (i + bufsize >= STRSIZE)
+			return;
 		(void) strcat(string, " (UTC)");
 	}
 }
@@ -427,7 +462,7 @@ dayhrminsec(long timeCount, int tzoffset, char *string)
 static void
 drawaled(ModeInfo * mi, int startx, int starty, int aled)
 {
-	Display    *display = MI_DISPLAY(mi);
+	Display *display = MI_DISPLAY(mi);
 	dclockstruct *dp = &dclocks[MI_SCREEN(mi)];
  	int x_1, y_1, x_2, y_2;
 
@@ -446,8 +481,10 @@ drawaled(ModeInfo * mi, int startx, int starty, int aled)
 				x_1, y_1, x_2, y_2);
 			break;
 		case 1: /* b */
-			x_1 = startx + dp->parallelogram[0].x + dp->parallelogram[1].x;
-			y_1 = starty + dp->parallelogram[0].y + dp->parallelogram[1].y;
+			x_1 = startx + dp->parallelogram[0].x +
+				dp->parallelogram[1].x;
+			y_1 = starty + dp->parallelogram[0].y +
+				dp->parallelogram[1].y;
 			x_2 = x_1 + dp->parallelogram[2].x / 2 + leanoffset;
 			y_2 = y_1 + dp->parallelogram[2].y / 2 - offset2;
 			x_1 = x_1 - leanoffset;
@@ -456,8 +493,12 @@ drawaled(ModeInfo * mi, int startx, int starty, int aled)
 				x_1, y_1, x_2, y_2);
 			break;
 		case 2: /* c */
-			x_1 = startx + dp->parallelogram[0].x + dp->parallelogram[1].x + dp->parallelogram[2].x;
-			y_1 = starty + dp->parallelogram[0].y + dp->parallelogram[1].y + dp->parallelogram[2].y;
+			x_1 = startx + dp->parallelogram[0].x +
+				dp->parallelogram[1].x +
+				dp->parallelogram[2].x;
+			y_1 = starty + dp->parallelogram[0].y +
+				dp->parallelogram[1].y +
+				dp->parallelogram[2].y;
 			x_2 = x_1 - dp->parallelogram[2].x / 2 - leanoffset;
 			y_2 = y_1 - dp->parallelogram[2].y / 2 + offset2;
 			x_1 = x_1 + leanoffset;
@@ -466,8 +507,10 @@ drawaled(ModeInfo * mi, int startx, int starty, int aled)
 				x_1, y_1, x_2, y_2);
 			break;
 		case 3: /* d */
-			x_1 = startx + dp->parallelogram[0].x + dp->parallelogram[2].x;
-			y_1 = starty + dp->parallelogram[0].y + dp->parallelogram[2].y;
+			x_1 = startx + dp->parallelogram[0].x +
+				dp->parallelogram[2].x;
+			y_1 = starty + dp->parallelogram[0].y +
+				dp->parallelogram[2].y;
 			x_2 = x_1 + dp->parallelogram[1].x - offset;
 			y_2 = y_1 + dp->parallelogram[1].y;
 			x_1 = x_1 + offset;
@@ -475,8 +518,10 @@ drawaled(ModeInfo * mi, int startx, int starty, int aled)
 				x_1, y_1, x_2, y_2);
 			break;
 		case 4: /* e */
-			x_1 = startx + dp->parallelogram[0].x + dp->parallelogram[2].x;
-			y_1 = starty + dp->parallelogram[0].y + dp->parallelogram[2].y;
+			x_1 = startx + dp->parallelogram[0].x +
+				dp->parallelogram[2].x;
+			y_1 = starty + dp->parallelogram[0].y +
+				dp->parallelogram[2].y;
 			x_2 = x_1 - dp->parallelogram[2].x / 2 - leanoffset;
 			y_2 = y_1 - dp->parallelogram[2].y / 2 + offset2;
 			x_1 = x_1 + leanoffset;
@@ -495,8 +540,10 @@ drawaled(ModeInfo * mi, int startx, int starty, int aled)
 				x_1, y_1, x_2, y_2);
 			break;
 		case 6: /* g */
-			x_1 = startx + dp->parallelogram[0].x + dp->parallelogram[2].x / 2;
-			y_1 = starty + dp->parallelogram[0].y + dp->parallelogram[2].y / 2;
+			x_1 = startx + dp->parallelogram[0].x +
+				dp->parallelogram[2].x / 2;
+			y_1 = starty + dp->parallelogram[0].y +
+				dp->parallelogram[2].y / 2;
 			x_2 = x_1 + dp->parallelogram[1].x - offset;
 			y_2 = y_1 + dp->parallelogram[1].y;
 			x_1 = x_1 + offset;
@@ -509,7 +556,7 @@ drawaled(ModeInfo * mi, int startx, int starty, int aled)
 static void
 drawacolon(ModeInfo * mi, int startx, int starty)
 {
-	Display    *display = MI_DISPLAY(mi);
+	Display *display = MI_DISPLAY(mi);
 	dclockstruct *dp = &dclocks[MI_SCREEN(mi)];
  	int x_1, y_1, x_2, y_2;
 
@@ -543,6 +590,34 @@ drawanumber(ModeInfo * mi, int startx, int starty, int digit)
 	}
 }
 
+static void
+drawadot(ModeInfo * mi, int startx, int starty, int filled)
+{
+	Display *display = MI_DISPLAY(mi);
+	dclockstruct *dp = &dclocks[MI_SCREEN(mi)];
+
+	if (filled)
+		XFillArc(display, dp->pixmap, dp->fgGC, startx, starty, 
+			BINARY_WIDTH, BINARY_HEIGHT, 0, 23040);
+	else
+		XDrawArc(display, dp->pixmap, dp->fgGC, startx, starty, 
+			BINARY_WIDTH, BINARY_HEIGHT, 0, 23040);
+}
+
+static void
+drawabinary(ModeInfo * mi, int startx, int starty, int dotcount, int digit)
+{
+	int newy;
+	int filled;
+	int i;
+
+	for (i=0; i < dotcount; i++) {
+		newy = starty + ((BINARY_HEIGHT + BINARY_INC) * (3 - i));
+		filled = (digit >> i) & 0x01;
+		drawadot(mi, startx, newy, filled);
+	}
+}
+
 static void
 free_dclock(Display *display, dclockstruct *dp)
 {
@@ -558,21 +633,23 @@ free_dclock(Display *display, dclockstruct *dp)
 		XFreePixmap(display, dp->pixmap);
 		dp->pixmap = None;
 	}
-}
+ }
 
 static void
 drawDclock(ModeInfo * mi)
 {
-	Display    *display = MI_DISPLAY(mi);
-	Window      window = MI_WINDOW(mi);
-	GC          gc = MI_GC(mi);
+	Display *display = MI_DISPLAY(mi);
+	Window window = MI_WINDOW(mi);
+	GC gc = MI_GC(mi);
 	dclockstruct *dp = &dclocks[MI_SCREEN(mi)];
-	short       xold, yold;
+	short xold, yold;
+	int i, j;
 
-	if (dp->led) {
+	if (!(message && *message)) {
+	  if (dp->led || dp->binary) {
 		dp->timeold = dp->timenew = time((time_t *) NULL);
 		dp->str = ctime(&dp->timeold);
-	} else if (!dp->popex && !dp->forest && !dp->hiv &&
+	  } else if (!dp->popex && !dp->forest && !dp->hiv &&
 	    !dp->lab && !dp->veg && !dp->y2k && !dp->millennium) {
 		if (dp->timeold != (dp->timenew = time((time_t *) NULL))) {
 			/* only parse if time has changed */
@@ -581,108 +658,110 @@ drawDclock(ModeInfo * mi)
 			if (!dp->popex && !dp->forest && !dp->hiv && !dp->lab &&
 			    !dp->veg && !dp->y2k && !dp->millennium) {
 			  if (dp->time24)
-				(void) strftime(dp->str1pta, STRSIZE, "%H:%M:%S", localtime(&(dp->timeold)));
+				(void) strftime(dp->strpta[0], STRSIZE,
+					"%H:%M:%S", localtime(&(dp->timeold)));
 			  else
-				(void) strftime(dp->str1pta, STRSIZE, "%I:%M:%S %p", localtime(&(dp->timeold)));
+				(void) strftime(dp->strpta[0], STRSIZE,
+					"%I:%M:%S %p", localtime(&(dp->timeold)));
 			}
-			(void) strftime(dp->str2pta, STRSIZE, "%a %b %d %Y", localtime(&(dp->timeold)));
+			(void) strftime(dp->strpta[1], STRSIZE,
+				"%a %b %d %Y", localtime(&(dp->timeold)));
 		}
-	} else {
+	  } else {
 		long timeNow, timeLocal;
 		timeNow = seconds();
 		timeLocal = timeNow - dp->tzoffset;
 
 		if (dp->popex) {
-			convert(PEOPLE_TIME_START + (PEOPLE_MIN / 60.0) * timeNow, dp->str2);
-			(void) strncat(dp->str2, PEOPLE_STRING, STRSIZE-strlen(dp->str2));
-			dp->str2pta = dp->str2;
-			dp->str2ptb = dp->str2pta;
+			convert(PEOPLE_TIME_START + (PEOPLE_MIN / 60.0) * timeNow, dp->strnew[1]);
+			(void) strncat(dp->strnew[1], PEOPLE_STRING,
+				STRSIZE-strlen(dp->strnew[1]));
+			dp->strpta[1] = dp->strnew[1];
+			dp->strptb[1] = dp->strpta[1];
 		} else if (dp->forest) {
-			convert(AREA_TIME_START - (AREA_MIN / 60.0) * timeNow, dp->str2);
-			(void) strncat(dp->str2, TROPICAL_STRING, STRSIZE-strlen(dp->str2));
-			(void) strncat(dp->str2, AREA_STRING, STRSIZE-strlen(dp->str2));
-			dp->str2pta = dp->str2;
-			dp->str2ptb = dp->str2pta;
+			convert(AREA_TIME_START - (AREA_MIN / 60.0) * timeNow, dp->strnew[1]);
+			(void) strncat(dp->strnew[1], TROPICAL_STRING,
+				STRSIZE-strlen(dp->strnew[1]));
+			(void) strncat(dp->strnew[1], AREA_STRING,
+				STRSIZE-strlen(dp->strnew[1]));
+			dp->strpta[1] = dp->strnew[1];
+			dp->strptb[1] = dp->strpta[1];
 		} else if (dp->hiv) {
-			convert(HIV_TIME_START + (HIV_MIN / 60.0) * timeNow, dp->str2);
-			(void) strncat(dp->str2, CASES_STRING, STRSIZE-strlen(dp->str2));
-			dp->str2pta = dp->str2;
-			dp->str2ptb = dp->str2pta;
+			convert(HIV_TIME_START + (HIV_MIN / 60.0) * timeNow, dp->strnew[1]);
+			(void) strncat(dp->strnew[1], CASES_STRING,
+				STRSIZE-strlen(dp->strnew[1]));
+			dp->strpta[1] = dp->strnew[1];
+			dp->strptb[1] = dp->strpta[1];
 		} else if (dp->lab) {
 			convert((LAB_MIN / 60.0) * (timeNow - timeAtLastNewYear(timeNow)),
-				dp->str2);
-			(void) strncat(dp->str2, YEAR_STRING, STRSIZE-strlen(dp->str2));
-			dp->str2pta = dp->str2;
-			dp->str2ptb = dp->str2pta;
+				dp->strnew[1]);
+			(void) strncat(dp->strnew[1], YEAR_STRING,
+				STRSIZE-strlen(dp->strnew[1]));
+			dp->strpta[1] = dp->strnew[1];
+			dp->strptb[1] = dp->strpta[1];
 		} else if (dp->veg) {
 			convert((VEG_MIN / 60.0) * (timeNow - timeAtLastNewYear(timeNow)),
-				dp->str2);
-			(void) strncat(dp->str2, YEAR_STRING, STRSIZE-strlen(dp->str2));
-			dp->str2pta = dp->str2;
-			dp->str2ptb = dp->str2pta;
+				dp->strnew[1]);
+			(void) strncat(dp->strnew[1], YEAR_STRING,
+				STRSIZE-strlen(dp->strnew[1]));
+			dp->strpta[1] = dp->strnew[1];
+			dp->strptb[1] = dp->strpta[1];
 		} else if (dp->y2k) {
 			if (Y2K_TIME_START >= timeLocal)
-				dp->str1pta = (char *) Y2K_STRING;
+				dp->strpta[0] = (char *) Y2K_STRING;
 			else
-				dp->str1pta = (char *) POST_Y2K_STRING;
-			dp->str1ptb = dp->str1pta;
-			dayhrminsec(Y2K_TIME_START - timeLocal, dp->tzoffset, dp->str2);
-			dp->str2pta = dp->str2;
-			dp->str2ptb = dp->str2pta;
+				dp->strpta[0] = (char *) POST_Y2K_STRING;
+			dp->strptb[0] = dp->strpta[0];
+			dayhrminsec(Y2K_TIME_START - timeLocal,
+				dp->tzoffset, dp->strnew[1]);
+			dp->strpta[1] = dp->strnew[1];
+			dp->strptb[1] = dp->strpta[1];
 		} else if (dp->millennium) {
 			if (Y2001_TIME_START >= timeLocal)
-				dp->str1pta = (char *) Y2001_STRING;
+				dp->strpta[0] = (char *) Y2001_STRING;
 			else
-				dp->str1pta = (char *) POST_Y2001_STRING;
-			dp->str1ptb = dp->str1pta;
-			dayhrminsec(Y2001_TIME_START - timeLocal, dp->tzoffset, dp->str2);
-			dp->str2pta = dp->str2;
-			dp->str2ptb = dp->str2pta;
+				dp->strpta[0] = (char *) POST_Y2001_STRING;
+			dp->strptb[0] = dp->strpta[0];
+			dayhrminsec(Y2001_TIME_START - timeLocal, dp->tzoffset, dp->strnew[1]);
+			dp->strpta[1] = dp->strnew[1];
+			dp->strptb[1] = dp->strpta[1];
 		}
+	  }
 	}
 	/* Recalculate string width since it can change */
 	xold = dp->clockx;
 	yold = dp->clocky;
-	if (!dp->led) {
-#ifdef USE_MB
-		{
-			XRectangle ink, logical;
-
-			XmbTextExtents(mode_font, dp->str1pta, strlen(dp->str1pta), &ink, &logical);
-			dp->text_width1 = logical.width;
-			XmbTextExtents(mode_font, dp->str2pta, strlen(dp->str2pta), &ink, &logical);
-			dp->text_width2 = logical.width;
+	if (!dp->led && !dp->binary) {
+		j = 0;
+		for (i = 0; i < dp->lines; i++) {
+			if (dp->strpta[i] && *(dp->strpta[i]))
+				dp->textWidth[i] = getTextWidth(dp->strpta[i]);
+			if (dp->textWidth[i] > dp->textWidth[j]) {
+				j = i;
+			}
 		}
-#else
-		dp->text_width1 = XTextWidth(mode_font, dp->str1pta, strlen(dp->str1pta));
-		dp->text_width2 = XTextWidth(mode_font, dp->str2pta, strlen(dp->str2pta));
-#endif
-
-		if (dp->text_width1 > dp->text_width2) {
-			dp->text_width = dp->text_width1;
-			dp->text_start1 = 0;
-			dp->text_start2 = (dp->text_width - dp->text_width2) / 2;
-		} else {
-			dp->text_width = dp->text_width2;
-			dp->text_start1 = (dp->text_width - dp->text_width1) / 2;
-			dp->text_start2 = 0;
+		dp->text_width = dp->textWidth[j];
+		for (i = 0; i < dp->lines; i++) {
+			dp->textStart[i] = (dp->text_width -
+				dp->textWidth[i]) / 2;
 		}
 	}
 	dp->width = MI_WIDTH(mi);
 	dp->height = MI_HEIGHT(mi);
 	dp->maxx = dp->width - dp->text_width;
-	dp->maxy = dp->height - dp->text_height - dp->text_descent;
+	dp->maxy = dp->height - (dp->lines - 1) * dp->text_height -
+		dp->text_descent;
 	dp->clockx += dp->dx;
 	dp->clocky += dp->dy;
-	if (dp->maxx < dp->text_start1) {
-		if (dp->clockx < dp->maxx + dp->text_start1 ||
-		    dp->clockx > dp->text_start1) {
+	if (dp->maxx < dp->textStart[0]) {
+		if (dp->clockx < dp->maxx + dp->textStart[0] ||
+				dp->clockx > dp->textStart[0]) {
 			dp->dx = -dp->dx;
 			dp->clockx += dp->dx;
 		}
-	} else if (dp->maxx > dp->text_start1) {
-		if (dp->clockx >= dp->maxx + dp->text_start1 ||
-		    dp->clockx <= dp->text_start1) {
+	} else if (dp->maxx > dp->textStart[0]) {
+		if (dp->clockx >= dp->maxx + dp->textStart[0] ||
+				dp->clockx <= dp->textStart[0]) {
 			dp->dx = -dp->dx;
 			dp->clockx += dp->dx;
 		}
@@ -699,8 +778,8 @@ drawDclock(ModeInfo * mi)
 		}
 	}
 	if (dp->pixw != dp->text_width ||
-	    dp->pixh != (1 + !dp->led) * dp->text_height) {
-		XGCValues   gcv;
+			dp->pixh != dp->lines * dp->text_height) {
+		XGCValues gcv;
 
 		if (dp->pixmap)
 			MI_CLEARWINDOWCOLORMAPFAST(mi, gc, MI_BLACK_PIXEL(mi));
@@ -709,9 +788,9 @@ drawDclock(ModeInfo * mi)
 		if (dp->led)
 			dp->pixh = dp->text_height;
 		else
-			dp->pixh = (2 + DELTA) * dp->text_height;
-		if ((dp->pixmap =
-			XCreatePixmap(display, window, dp->pixw, dp->pixh, 1)) == None) {
+			dp->pixh = (dp->lines + DELTA) * dp->text_height;
+		if ((dp->pixmap = XCreatePixmap(display, window,
+				dp->pixw, dp->pixh, 1)) == None) {
 			free_dclock(display, dp);
 			dp->pixw = 0;
 			dp->pixh = 0;
@@ -746,12 +825,13 @@ drawDclock(ModeInfo * mi)
 			dp->pixh = 0;
 			return;
 		}
-		XSetLineAttributes(display, dp->fgGC,
-		  (unsigned int) (LED_WIDTH),
-		  LineSolid, CapButt, JoinMiter);
+		if (!dp->binary)
+			XSetLineAttributes(display, dp->fgGC,
+				(unsigned int) (LED_WIDTH),
+				LineSolid, CapButt, JoinMiter);
 	}
-	XFillRectangle(display, dp->pixmap, dp->bgGC, 0, 0, dp->pixw, dp->pixh);
-
+	XFillRectangle(display, dp->pixmap, dp->bgGC,
+		0, 0, dp->pixw, dp->pixh);
 	if (dp->led) {
 		int startx = (int) (LED_WIDTH / 2.0);
 		int starty = (int) (LED_WIDTH / 2.0);
@@ -771,22 +851,35 @@ drawDclock(ModeInfo * mi)
 		drawanumber(mi, startx, starty, dp->str[17] - '0');
 		startx += (int) (LED_XS + LED_WIDTH + LED_INC);
 		drawanumber(mi, startx, starty, dp->str[18] - '0');
+	} else if (dp->binary) {
+		int startx = BINARY_WIDTH / 2;
+		int starty = BINARY_HEIGHT / 2;
+
+		/* hour - top number, 0, 1 or 2 */
+		drawabinary(mi, startx, starty, 2, dp->str[11] - '0');
+		startx += (BINARY_WIDTH + BINARY_INC);
+		/* hour - bottom number 0 - 9 */
+		drawabinary(mi, startx, starty, 4, dp->str[12] - '0');
+		startx += (BINARY_WIDTH + BINARY_INC);
+		/* minute - top number, 0 - 5 */
+		drawabinary(mi, startx, starty, 3, dp->str[14] - '0');
+		startx += (BINARY_WIDTH + BINARY_INC);
+		/* minute - bottom number, 0 - 9 */
+		drawabinary(mi, startx, starty, 4, dp->str[15] - '0');
+		startx += (BINARY_WIDTH + BINARY_INC);
+		/* second - top number, 0 - 5 */
+		drawabinary(mi, startx, starty, 3, dp->str[17] - '0');
+		startx += (BINARY_WIDTH + BINARY_INC);
+		/* second - bottom number, 0 - 9 */
+		drawabinary(mi, startx, starty, 4, dp->str[18] - '0');
+		startx += (BINARY_WIDTH + BINARY_INC);
 	} else {
-#ifdef USE_MB
-		(void) XmbDrawString(display, dp->pixmap, mode_font, dp->fgGC,
-			dp->text_start1, dp->text_ascent,
-			dp->str1pta, strlen(dp->str1pta));
-		(void) XmbDrawString(display, dp->pixmap, mode_font, dp->fgGC,
-			dp->text_start2, dp->text_ascent + dp->text_height,
-			dp->str2pta, strlen(dp->str2pta));
-#else
-		(void) XDrawString(display, dp->pixmap, dp->fgGC,
-			dp->text_start1, dp->text_ascent,
-			dp->str1pta, strlen(dp->str1pta));
-		(void) XDrawString(display, dp->pixmap, dp->fgGC,
-			dp->text_start2, dp->text_ascent + dp->text_height,
-			dp->str2pta, strlen(dp->str2pta));
-#endif
+		for (i = 0; i < dp->lines; i++) {
+			DrawString(display, dp->pixmap, dp->fgGC,
+				dp->textStart[i],
+				dp->text_ascent + i * dp->text_height,
+				dp->strpta[i], strlen(dp->strpta[i]));
+		}
 	}
 
 	XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
@@ -795,31 +888,39 @@ drawDclock(ModeInfo * mi)
 	   ... this is solved by the ClearWindow above
 	 */
 	ERASE_IMAGE(display, window, gc,
-	    (dp->clockx - dp->text_start1), (dp->clocky - dp->text_ascent),
-		    (xold - dp->text_start1), (yold - dp->text_ascent),
-		    dp->pixw, dp->pixh);
+		(dp->clockx - dp->textStart[0]),
+		(dp->clocky - dp->text_ascent),
+		(xold - dp->textStart[0]), (yold - dp->text_ascent),
+		dp->pixw, dp->pixh);
 	if (MI_NPIXELS(mi) > 2)
 		XSetForeground(display, gc, MI_PIXEL(mi, dp->color));
 	else
 		XSetForeground(display, gc, MI_WHITE_PIXEL(mi));
 	XCopyPlane(display, dp->pixmap, window, gc,
-		   0, 0, dp->text_width, (2 + DELTA) * dp->text_height,
-		dp->clockx - dp->text_start1, dp->clocky - dp->text_ascent,
-		   1L);
+		0, 0, dp->text_width, (dp->lines + DELTA) * dp->text_height,
+		dp->clockx - dp->textStart[0], dp->clocky - dp->text_ascent,
+		1L);
 }
 
 void
 release_dclock(ModeInfo * mi)
 {
 	if (dclocks != NULL) {
-		int         screen;
+		int screen;
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_dclock(MI_DISPLAY(mi), &dclocks[screen]);
 		free(dclocks);
 		dclocks = (dclockstruct *) NULL;
 	}
-	free_font(MI_DISPLAY(mi));
+	if (mode_font != None) {
+#ifdef USE_MB
+		XFreeFontSet(MI_DISPLAY(mi), mode_font);
+#else
+		XFreeFont(MI_DISPLAY(mi), mode_font);
+#endif
+		mode_font = None;
+	}
 }
 
 #if defined(HAVE_TZSET) && !(defined(BSD) && BSD >= 199306) && !(defined(__CYGWIN__))
@@ -829,16 +930,17 @@ extern long timezone;
 void
 init_dclock(ModeInfo * mi)
 {
-	Display    *display = MI_DISPLAY(mi);
+	Display *display = MI_DISPLAY(mi);
 	dclockstruct *dp;
 	long timeNow, timeLocal;
+	int i, j;
 
 	if (dclocks == NULL) {
 #ifndef HAVE_SNPRINTF
 		logbase = log(BASE);
 #endif
 		if ((dclocks = (dclockstruct *) calloc(MI_NUM_SCREENS(mi),
-					     sizeof (dclockstruct))) == NULL)
+				sizeof (dclockstruct))) == NULL)
 			return;
 	}
 	dp = &dclocks[MI_SCREEN(mi)];
@@ -848,6 +950,7 @@ init_dclock(ModeInfo * mi)
 
 	MI_CLEARWINDOW(mi);
 
+	dp->binary = False;
 	dp->led = False;
 	dp->popex = False;
 	dp->forest = False;
@@ -857,19 +960,21 @@ init_dclock(ModeInfo * mi)
 	dp->time24 = False;
 	dp->y2k = False;
 	dp->millennium = False;
+	dp->lines = 2;
 #if defined(MODE_dclock_y2k) && defined(MODE_dclock_millennium)
-#define NUM_DCLOCK_MODES 10
+#define NUM_DCLOCK_MODES 11
 #endif
 #if defined(MODE_dclock_y2k) && !defined(MODE_dclock_millennium)
-#define NUM_DCLOCK_MODES 9
+#define NUM_DCLOCK_MODES 10
 #endif
 #if !defined(MODE_dclock_y2k) && defined(MODE_dclock_millennium)
-#define NUM_DCLOCK_MODES 9
+#define NUM_DCLOCK_MODES 10
 #endif
 #if !defined(MODE_dclock_y2k) && !defined(MODE_dclock_millennium)
-#define NUM_DCLOCK_MODES 8
+#define NUM_DCLOCK_MODES 9
 #endif
-	if (MI_IS_FULLRANDOM(mi)) {
+	if (!(message && *message)) {
+	    if (MI_IS_FULLRANDOM(mi)) {
 		switch (NRAND(NUM_DCLOCK_MODES)) {
 			case 0:
 				break;
@@ -894,8 +999,11 @@ init_dclock(ModeInfo * mi)
 			case 7:
 				dp->time24 = True;
 				break;
-#if defined(MODE_dclock_y2k) || defined(MODE_dclock_millennium)
 			case 8:
+				dp->binary = True;
+				break;
+#if defined(MODE_dclock_y2k) || defined(MODE_dclock_millennium)
+			case 9:
 #ifdef MODE_dclock_y2k
 				dp->y2k = True;
 #else
@@ -903,7 +1011,7 @@ init_dclock(ModeInfo * mi)
 #endif
 				break;
 #if defined(MODE_dclock_y2k) && defined(MODE_dclock_millennium)
-			case 9:
+			case 10:
 				dp->millennium = True;
 				break;
 #endif
@@ -911,7 +1019,8 @@ init_dclock(ModeInfo * mi)
 			default:
 				break;
 		}
-	} else { /* first come, first served */
+	    } else { /* first come, first served */
+		dp->binary = binary;
 		dp->led = led;
 		dp->popex = popex;
 		dp->forest = forest;
@@ -921,6 +1030,7 @@ init_dclock(ModeInfo * mi)
 		dp->time24 = time24;
 		dp->y2k = y2k;
 		dp->millennium = millennium;
+	    }
 	}
 
 	if (mode_font == None) {
@@ -934,13 +1044,6 @@ init_dclock(ModeInfo * mi)
 			return;
 		}
 	}
-	if (!dp->done) {
-		dp->done = 1;
-#ifndef USE_MB
-		if (mode_font != None)
-			XSetFont(display, MI_GC(mi), mode_font->fid);
-#endif
-	}
 	/* (void)time(&dp->timenew); */
 #if defined(HAVE_TZSET) && (!defined(HAVE_TIMELOCAL) || (defined(BSD) && BSD >= 199306))
 	(void) tzset();
@@ -951,7 +1054,7 @@ init_dclock(ModeInfo * mi)
 		mktime(gmtime(&dp->timeold));
 #else
 #if defined(HAVE_TZSET)
-        dp->tzoffset = (int)timezone;
+	dp->tzoffset = (int)timezone;
 #else
 	dp->tzoffset = 0;
 #endif
@@ -965,28 +1068,30 @@ init_dclock(ModeInfo * mi)
 	timeNow = seconds();
 	timeLocal = timeNow - dp->tzoffset;
 	if (dp->led) {
-		int i;
-
+		dp->lines = 1;
 		dp->text_descent = 0;
 		dp->text_ascent = 0;
 		for (i = 0; i < 4; i++) {
 			if (parallelogramUnit[i].x == 1)
-				dp->parallelogram[i].x = (short) (LED_XS * LED_LEAN);
+				dp->parallelogram[i].x = (short) (LED_XS *
+					LED_LEAN);
 			else if (parallelogramUnit[i].x == 2)
 				dp->parallelogram[i].x = (short) LED_XS;
 			else if (parallelogramUnit[i].x == -1)
-				dp->parallelogram[i].x = (short) (-LED_XS * LED_LEAN);
+				dp->parallelogram[i].x = (short) (-LED_XS *
+					LED_LEAN);
 			else if (parallelogramUnit[i].x == -2)
 				dp->parallelogram[i].x = (short) (-LED_XS);
 			else
 				dp->parallelogram[i].x = 0;
-			dp->parallelogram[i].y = (short) (LED_YS * parallelogramUnit[i].y);
+			dp->parallelogram[i].y = (short) (LED_YS *
+					parallelogramUnit[i].y);
 		}
-
-		dp->parallelogram[0].x = (short) ((LED_XS * LED_LEAN) + LED_INC);
+		dp->parallelogram[0].x = (short) ((LED_XS * LED_LEAN) +
+			LED_INC);
 		dp->parallelogram[0].y = (short) LED_INC;
 		dp->text_width = (short) (6 * (LED_XS + LED_WIDTH + LED_INC) +
-		  2 * (LED_WIDTH + LED_INC) + LED_XS * LED_LEAN - LED_INC);
+			2 * (LED_WIDTH + LED_INC) + LED_XS * LED_LEAN - LED_INC);
 		dp->text_height = (short) (LED_YS + LED_WIDTH + LED_INC);
 		dp->maxy = dp->height - dp->text_height;
 		if (dp->maxy == 0)
@@ -995,130 +1100,159 @@ init_dclock(ModeInfo * mi)
 			dp->clocky = -NRAND(-dp->maxy);
 		else
 			dp->clocky = NRAND(dp->maxy);
+	} else if (dp->binary) {
+		dp->text_width = (6 * (BINARY_WIDTH + BINARY_INC)) +
+			BINARY_WIDTH;
+		dp->text_height = (4 * (BINARY_HEIGHT + BINARY_INC)) +
+			BINARY_HEIGHT;
+		dp->maxy = dp->height - (dp->lines - 1) * dp->text_height;
+		if (dp->maxy == 0)
+			dp->clocky = 0;
+		else if (dp->maxy < 0)
+			dp->clocky = -NRAND(-dp->maxy);
+		else
+			dp->clocky = NRAND(dp->maxy);
 	} else {
 #ifdef USE_MB
 		dp->text_descent = 0;
-		dp->text_ascent = font_height(mode_font);
+		dp->text_ascent = getFontHeight(mode_font);
 #else
 		dp->text_descent = mode_font->descent;
 		dp->text_ascent = mode_font->ascent;
 #endif
-		if (dp->popex) {
-			dp->str1pta = (char *) POPEX_STRING;
-			dp->str1ptb = dp->str1pta;
+		if (message && *message) {
+			char *p, *p2, *p3, buf[BUFSIZ]; int width, height, w;
+
+			p = strncpy(buf, message, BUFSIZ);
+			while (strlen(p) > 0) {
+				p2 = p + strlen(p) - 1;
+				if (*p2 == '\n')
+					*p2 = 0;
+				else
+					break;
+			}
+			for (height = 0; p && height < MAXLINES; height++) {
+				if (!(p2 = (char *) strchr(p, '\n')) ||
+						!p2[1]) {
+					p2 = p + strlen(p);
+				}
+				/* p2 now points to the first '\n' */
+				*p2 = 0;
+				for (w = 0; w < p2 - p; w++) {
+					p3 = p + w;
+					if (*p3 == '\t') /* this should be improved */
+						*p3 = ' ';
+				}
+				(void) strncpy(dp->strnew[height], p,
+					MAXWIDTH - 1);
+				dp->strpta[height] = dp->strnew[height];
+				dp->strptb[height] = dp->strpta[height];
+				dp->strpta[height][MAXWIDTH - 1] = '\0';
+				if (p == p2)
+					break;
+				p = p2 + 1;
+			}
+			dp->lines = height;
+		} else if (dp->popex) {
+			dp->strpta[0] = (char *) POPEX_STRING;
+			dp->strptb[0] = dp->strpta[0];
+			convert(PEOPLE_TIME_START + (PEOPLE_MIN / 60.0) * timeNow, dp->strnew[1]);
+			(void) strncat(dp->strnew[1], PEOPLE_STRING, STRSIZE-strlen(dp->strnew[1]));
+			dp->strpta[1] = dp->strnew[1];
+			dp->strptb[1] = dp->strpta[1];
 		} else if (dp->forest) {
-			dp->str1pta = (char *) FOREST_STRING;
-			dp->str1ptb = dp->str1pta;
+			dp->strpta[0] = (char *) FOREST_STRING;
+			dp->strptb[0] = dp->strpta[0];
+			convert(AREA_TIME_START - (AREA_MIN / 60.0) * timeNow, dp->strnew[1]);
+			(void) strncat(dp->strnew[1], TROPICAL_STRING, STRSIZE-strlen(dp->strnew[1]));
+			(void) strncat(dp->strnew[1], AREA_STRING, STRSIZE-strlen(dp->strnew[1]));
+			dp->strpta[1] = dp->strnew[1];
+			dp->strptb[1] = dp->strpta[1];
 		} else if (dp->hiv) {
-			dp->str1pta = (char *) HIV_STRING;
-			dp->str1ptb = dp->str1pta;
+			dp->strpta[0] = (char *) HIV_STRING;
+			dp->strptb[0] = dp->strpta[0];
+			convert(HIV_TIME_START + (HIV_MIN / 60.0) * timeNow, dp->strnew[1]);
+			(void) strncat(dp->strnew[1], CASES_STRING, STRSIZE-strlen(dp->strnew[1]));
+			dp->strpta[1] = dp->strnew[1];
+			dp->strptb[1] = dp->strpta[1];
 		} else if (dp->lab) {
-			dp->str1pta = (char *) LAB_STRING;
-			dp->str1ptb = dp->str1pta;
+			dp->strpta[0] = (char *) LAB_STRING;
+			dp->strptb[0] = dp->strpta[0];
+			convert((LAB_MIN / 60.0) * (timeNow - timeAtLastNewYear(timeNow)),
+				dp->strnew[1]);
+			(void) strncat(dp->strnew[1], YEAR_STRING, STRSIZE-strlen(dp->strnew[1]));
+			dp->strpta[1] = dp->strnew[1];
+			dp->strptb[1] = dp->strpta[1];
 		} else if (dp->veg) {
-			dp->str1pta = (char *) VEG_STRING;
-			dp->str1ptb = dp->str1pta;
+			dp->strpta[0] = (char *) VEG_STRING;
+			dp->strptb[0] = dp->strpta[0];
+			convert((VEG_MIN / 60.0) * (timeNow - timeAtLastNewYear(timeNow)),
+				dp->strnew[1]);
+			(void) strncat(dp->strnew[1], YEAR_STRING, STRSIZE-strlen(dp->strnew[1]));
+			dp->strpta[1] = dp->strnew[1];
 		} else if (dp->y2k) {
 			if (Y2K_TIME_START >= timeLocal)
-				dp->str1pta = (char *) Y2K_STRING;
+				dp->strpta[0] = (char *) Y2K_STRING;
 			else
-				dp->str1pta = (char *) POST_Y2K_STRING;
-			dp->str1ptb = dp->str1pta;
+				dp->strpta[0] = (char *) POST_Y2K_STRING;
+			dp->strptb[0] = dp->strpta[0];
+			dayhrminsec(Y2K_TIME_START - timeLocal, dp->tzoffset, dp->strnew[1]);
+			dp->strpta[1] = dp->strnew[1];
 		} else if (dp->millennium) {
 			if (Y2001_TIME_START >= timeLocal)
-				dp->str1pta = (char *) Y2001_STRING;
+				dp->strpta[0] = (char *) Y2001_STRING;
 			else
-				dp->str1pta = (char *) POST_Y2001_STRING;
-			dp->str1ptb = dp->str1pta;
+				dp->strpta[0] = (char *) POST_Y2001_STRING;
+			dp->strptb[0] = dp->strpta[0];
+			dayhrminsec(Y2001_TIME_START - timeLocal, dp->tzoffset, dp->strnew[1]);
+			dp->strpta[1] = dp->strnew[1];
 		} else {
 			struct tm *t = localtime((const time_t *) &timeLocal);
 
 			if (dp->time24)
-			  (void) strftime(dp->str1, STRSIZE, "%H:%M:%S", t);
+			  (void) strftime(dp->strnew[0], STRSIZE, "%H:%M:%S", t);
 			else
-			  (void) strftime(dp->str1, STRSIZE, "%I:%M:%S %p", t);
+			  (void) strftime(dp->strnew[0], STRSIZE, "%I:%M:%S %p", t);
 			dp->hour = t->tm_hour;
-			(void) strftime(dp->str2, STRSIZE, "%a %b %d %Y", t);
+			(void) strftime(dp->strnew[1], STRSIZE, "%a %b %d %Y", t);
 
-			dp->str1pta = dp->str1;
-			dp->str1ptb = dp->str1old;
+			dp->strpta[0] = dp->strnew[0];
+			dp->strptb[0] = dp->strold[0];
+			dp->strpta[1] = dp->strnew[1];
+			dp->strptb[1] = dp->strold[1];
 		}
-		if (dp->popex) {
-			convert(PEOPLE_TIME_START + (PEOPLE_MIN / 60.0) * timeNow, dp->str2);
-			(void) strncat(dp->str2, PEOPLE_STRING, STRSIZE-strlen(dp->str2));
-			dp->str2pta = dp->str2;
-			dp->str2ptb = dp->str2pta;
-		} else if (dp->forest) {
-			convert(AREA_TIME_START - (AREA_MIN / 60.0) * timeNow, dp->str2);
-			(void) strncat(dp->str2, TROPICAL_STRING, STRSIZE-strlen(dp->str2));
-			(void) strncat(dp->str2, AREA_STRING, STRSIZE-strlen(dp->str2));
-			dp->str2pta = dp->str2;
-			dp->str2ptb = dp->str2pta;
-		} else if (dp->hiv) {
-			convert(HIV_TIME_START + (HIV_MIN / 60.0) * timeNow, dp->str2);
-			(void) strncat(dp->str2, CASES_STRING, STRSIZE-strlen(dp->str2));
-			dp->str2pta = dp->str2;
-			dp->str2ptb = dp->str2pta;
-		} else if (dp->lab) {
-			convert((LAB_MIN / 60.0) * (timeNow - timeAtLastNewYear(timeNow)),
-				dp->str2);
-			(void) strncat(dp->str2, YEAR_STRING, STRSIZE-strlen(dp->str2));
-			dp->str2pta = dp->str2;
-			dp->str2ptb = dp->str2pta;
-		} else if (dp->veg) {
-			convert((VEG_MIN / 60.0) * (timeNow - timeAtLastNewYear(timeNow)),
-				dp->str2);
-			(void) strncat(dp->str2, YEAR_STRING, STRSIZE-strlen(dp->str2));
-			dp->str2pta = dp->str2;
-		} else if (dp->y2k) {
-			dayhrminsec(Y2K_TIME_START - timeLocal, dp->tzoffset, dp->str2);
-			dp->str2pta = dp->str2;
-		} else if (dp->millennium) {
-			dayhrminsec(Y2001_TIME_START - timeLocal, dp->tzoffset, dp->str2);
-			dp->str2pta = dp->str2;
-		} else {
-			dp->str2pta = dp->str2;
-			dp->str2ptb = dp->str2old;
+		dp->text_height = getFontHeight(mode_font);
+		j = 0;
+		for (i = 0; i < dp->lines; i++) {
+			if (dp->strpta[i] && *(dp->strpta[i]))
+				dp->textWidth[i] = getTextWidth(dp->strpta[i]);
+			if (dp->textWidth[i] > dp->textWidth[j]) {
+				j = i;
+			}
 		}
-
-		dp->text_height = font_height(mode_font);
-#ifdef USE_MB
-		{
-			XRectangle ink, logical;
-
-			XmbTextExtents(mode_font, dp->str1pta, strlen(dp->str1pta), &ink, &logical);
-			dp->text_width1 = logical.width;
-			XmbTextExtents(mode_font, dp->str2pta, strlen(dp->str2pta), &ink, &logical);
-			dp->text_width2 = logical.width;
+		dp->text_width = dp->textWidth[j];
+		for (i = 0; i < dp->lines; i++) {
+			dp->textStart[i] = (dp->text_width -
+				dp->textWidth[i]) / 2;
 		}
-#else
-		dp->text_width1 = XTextWidth(mode_font, dp->str1pta, strlen(dp->str1pta));
-		dp->text_width2 = XTextWidth(mode_font, dp->str2pta, strlen(dp->str2pta));
-#endif
-		if (dp->text_width1 > dp->text_width2) {
-			dp->text_width = dp->text_width1;
-			dp->text_start1 = 0;
-			dp->text_start2 = (dp->text_width - dp->text_width2) / 2;
-		} else {
-			dp->text_width = dp->text_width2;
-			dp->text_start1 = (dp->text_width - dp->text_width1) / 2;
-			dp->text_start2 = 0;
-		}
-		dp->maxy = dp->height - dp->text_height - dp->text_descent;
+		dp->maxy = dp->height - (dp->lines - 1) * dp->text_height -
+			dp->text_descent;
 		if (dp->maxy - dp->text_ascent == 0)
 			dp->clocky = dp->text_ascent;
 		else if (dp->maxy - dp->text_ascent < 0)
-			dp->clocky = -NRAND(dp->text_ascent - dp->maxy) + dp->text_ascent;
+			dp->clocky = -NRAND(dp->text_ascent - dp->maxy) +
+				dp->text_ascent;
 		else
-			dp->clocky = NRAND(dp->maxy - dp->text_ascent) + dp->text_ascent;
+			dp->clocky = NRAND(dp->maxy - dp->text_ascent) +
+				dp->text_ascent;
 	}
 	dp->maxx = dp->width - dp->text_width;
 	if (dp->maxx == 0)
-		dp->clockx = dp->text_start1;
+		dp->clockx = dp->textStart[0];
 	else if (dp->maxx < 0)
-		dp->clockx = -NRAND(-dp->maxx) + dp->text_start1;
+		dp->clockx = -NRAND(-dp->maxx) + dp->textStart[0];
 	else
-		dp->clockx = NRAND(dp->maxx) + dp->text_start1;
+		dp->clockx = NRAND(dp->maxx) + dp->textStart[0];
 
 	if (MI_NPIXELS(mi) > 2)
 		dp->color = NRAND(MI_NPIXELS(mi));
