@@ -20,8 +20,8 @@ static const char sccsid[] = "@(#)fire.c	5.02 2001/09/26 xlockmore";
  * event will the author be liable for any lost revenue or profits or
  * other special, indirect and consequential damages.
  *
- * The original code for this mode was written by David Bucciarelli 
- * (tech.hmw@plus.it) and could be found in the demo package 
+ * The original code for this mode was written by David Bucciarelli
+ * (tech.hmw@plus.it) and could be found in the demo package
  * of Mesa (Mesa-3.2/3Dfx/demos/). This mode is the result of the merge of
  * two of the David's demos (fire and rain).
  *
@@ -31,7 +31,7 @@ static const char sccsid[] = "@(#)fire.c	5.02 2001/09/26 xlockmore";
  * REVISION HISTORY:
  *
  * E.Lassauge - 26-Sep-2001:
- *      - add wander option and code 
+ *      - add wander option and code
  *      - cleanups for xscreensaver
  *
  * E.Lassauge - 09-Mar-2001:
@@ -193,12 +193,12 @@ static XrmOptionDescRec opts[] = {
 };
 
 static argtype vars[] = {
-    {(caddr_t *) & do_texture, (char *) "texture", (char *) "Texture", (char *) DEF_TEXTURE, t_Bool},
-    {(caddr_t *) & do_fog, (char *) "fog", (char *) "Fog", (char *) DEF_FOG, t_Bool},
-    {(caddr_t *) & do_shadows, (char *) "shadows", (char *) "Shadows", (char *) DEF_SHADOWS, t_Bool},
-    {(caddr_t *) & do_trackmouse, (char *) "trackmouse", (char *) "TrackMouse", (char *) DEF_TRACKMOUSE, t_Bool},
-    {(caddr_t *) & do_wander, (char *) "wander", (char *) "Wander", (char *) DEF_WANDER, t_Bool},
-    {(caddr_t *) & num_trees, (char *) "trees", (char *) "Trees", (char *) DEF_TREES, t_Int},
+    {(void *) & do_texture, (char *) "texture", (char *) "Texture", (char *) DEF_TEXTURE, t_Bool},
+    {(void *) & do_fog, (char *) "fog", (char *) "Fog", (char *) DEF_FOG, t_Bool},
+    {(void *) & do_shadows, (char *) "shadows", (char *) "Shadows", (char *) DEF_SHADOWS, t_Bool},
+    {(void *) & do_trackmouse, (char *) "trackmouse", (char *) "TrackMouse", (char *) DEF_TRACKMOUSE, t_Bool},
+    {(void *) & do_wander, (char *) "wander", (char *) "Wander", (char *) DEF_WANDER, t_Bool},
+    {(void *) & num_trees, (char *) "trees", (char *) "Trees", (char *) DEF_TREES, t_Int},
 };
 
 static OptionStruct desc[] = {
@@ -390,7 +390,7 @@ static void setnewrain(firestruct * fs, rain * r)
 
     vinit(r->acc,0.0f,-0.98f,0.0f);
     vinit(r->vel,0.0f,0.0f,0.0f);
-    
+
     r->partLength=0.2f;
 
     vinit(r->oldpos,fs->min[0]+(fs->max[0]-fs->min[0])*vrnd(),
@@ -603,7 +603,7 @@ static void inittextures(ModeInfo * mi)
 	      (void)fprintf(stderr,"Error reading tree texture.\n");
 	      glDeleteTextures(1, &fs->treeid);
 	      fs->treeid    = 0;
-              fs->num_trees = 0; 
+              fs->num_trees = 0;
 	      return;
 	    }
 
@@ -652,7 +652,7 @@ static Bool inittree(ModeInfo * mi)
       	    fs->treepos[i].z =vrnd()*TREEOUTR*2.0-TREEOUTR;
       	    dist=sqrt(fs->treepos[i].x *fs->treepos[i].x +fs->treepos[i].z *fs->treepos[i].z );
         } while((dist<TREEINR) || (dist>TREEOUTR));
-	return True;
+    return True;
 }
 
 /*
@@ -909,7 +909,7 @@ static Bool Init(ModeInfo * mi)
 	    setnewrain(fs, &(fs->r[i]));
     	}
     }
-    
+
     return True;
 }
 
