@@ -338,9 +338,9 @@ load_fonts (ModeInfo *mi)
 {
   molecule_configuration *mc = &mcs[MI_SCREEN(mi)];
 #ifdef STANDALONE
-  if (!load_font (mi, (char *) "atomFont",  &mc->xfont1, &mc->font1_dlist)
+  if (!load_font (mi, (char *) "atomFont",  &mc->xfont1, &mc->font1_dlist))
 	return False;
-  if (!load_font (mi, (char *) "titleFont", &mc->xfont2, &mc->font2_dlist)
+  if (!load_font (mi, (char *) "titleFont", &mc->xfont2, &mc->font2_dlist))
 	return False;
 #else
   if (!load_font (mi, (char *) "-*-times-bold-r-normal-*-240-*",
@@ -610,14 +610,17 @@ draw_bounding_box (ModeInfo *mi)
   glVertex3f(x2, y2, z2); glVertex3f(x2, y2, z1);
   glEnd();
 
-  glPushAttrib (GL_LIGHTING);
+  glPushAttrib (GL_LIGHTING_BIT);
   glDisable (GL_LIGHTING);
 
   glColor3f (c2[0], c2[1], c2[2]);
   glBegin(GL_LINES);
-  if (x1 > 0) x1 = 0; if (x2 < 0) x2 = 0;
-  if (y1 > 0) y1 = 0; if (y2 < 0) y2 = 0;
-  if (z1 > 0) z1 = 0; if (z2 < 0) z2 = 0;
+  if (x1 > 0) x1 = 0;
+  if (x2 < 0) x2 = 0;
+  if (y1 > 0) y1 = 0;
+  if (y2 < 0) y2 = 0;
+  if (z1 > 0) z1 = 0;
+  if (z2 < 0) z2 = 0;
   glVertex3f(x1, 0,  0);  glVertex3f(x2, 0,  0);
   glVertex3f(0 , y1, 0);  glVertex3f(0,  y2, 0);
   glVertex3f(0,  0,  z1); glVertex3f(0,  0,  z2);
@@ -676,7 +679,7 @@ print_title_string (ModeInfo *mi, const char *string,
 
   y -= line_height;
 
-  glPushAttrib (GL_LIGHTING | GL_DEPTH_TEST);
+  glPushAttrib (GL_LIGHTING_BIT | GL_DEPTH_BUFFER_BIT);
   glDisable (GL_LIGHTING);
   glDisable (GL_DEPTH_TEST);
   {
@@ -799,7 +802,7 @@ build_molecule (ModeInfo *mi)
 
       if (do_labels)
         {
-          glPushAttrib (GL_LIGHTING | GL_DEPTH_TEST);
+          glPushAttrib (GL_LIGHTING_BIT | GL_DEPTH_BUFFER_BIT);
           glDisable (GL_LIGHTING);
           glDisable (GL_DEPTH_TEST);
 
