@@ -117,7 +117,7 @@ static XrmOptionDescRec opts[] =
 
 static argtype vars[] =
 {
-	{(caddr_t *) & hideshuffling, (char *) "hideshuffling", (char *) "Hideshuffling", (char *) DEF_HIDESHUFFLING, t_Bool}
+	{(void *) & hideshuffling, (char *) "hideshuffling", (char *) "Hideshuffling", (char *) DEF_HIDESHUFFLING, t_Bool}
 };
 
 static OptionStruct desc[] =
@@ -1130,7 +1130,7 @@ rotateFace(skewbstruct * sp, int face, int direction)
 	}
 	sp->cubeLoc[face][MAXORIENT].rotation =
 		(sp->cubeLoc[face][MAXORIENT].rotation + direction) % MAXORIENT;
-	/* DrawDiamond(face); */ 
+	/* DrawDiamond(face); */
 }
 
 #ifdef HACK
@@ -1209,13 +1209,13 @@ moveSkewb(skewbstruct * sp, int face, int direction, int position)
 }
 
 #ifdef DEBUG
-void
+static void
 printCube(skewbstruct * sp)
 {
 	int	 face, position;
 
 	for (face = 0; face < MAXFACES; face++) {
-		for (position = 0; position < MAXCUBES; position++)
+		for (position = 0; position < MAXCUBES; position++) {
 			(void) printf("%d %d  ", sp->cubeLoc[face][position].face,
 			sp->cubeLoc[face][position].rotation);
 		}
