@@ -1766,7 +1766,7 @@ init_adam(ModeInfo * mi)
 		 start.y + j - lp->by,
 		 hex_self_reproducing_loop[j][i]);
 #endif
-  } else {
+	} else {
 		switch (dir) {
 			case 0:
 				start.x = (lp->bncols - SQ_ADAM_LOOPX(evolve)) / 2;
@@ -1839,8 +1839,8 @@ init_adam(ModeInfo * mi)
 		/* Draw right away */
 		drawcell(mi, start.x + dirx.x * i + diry.x * j - lp->bx,
 		 start.y + dirx.y * i + diry.y * j - lp->by,
-		 (evolve) ? ((lp->clockwise) ? evo_self_reproducing_loop[j][EVO__ADAM_LOOPX - i - i] : evo_self_reproducing_loop[j][i]) : ;
-		  ((lp->clockwise) ? self_reproducing_loop[j][ADAM_LOOPX - i - i] : self_reproducing_loop[j][i]));
+		 (evolve) ? ((lp->clockwise) ? evo_self_reproducing_loop[j][EVO_ADAM_LOOPX - i - 1] : evo_self_reproducing_loop[j][i]) :
+		  ((lp->clockwise) ? self_reproducing_loop[j][ADAM_LOOPX - i - 1] : self_reproducing_loop[j][i]));
 #endif
 	}
 }
