@@ -342,11 +342,11 @@ reps(complex c, double p, int r, Bool binary, interior_t interior, double demran
 	complex     dt;
 	double      L = 0.0;
 	double      l2;
-	double      dl2;
+	double      dl2 = 1.0;
 	double      alpha2 = ESCAPE;
 	int         index = 0;
 #if defined(USE_LOG)
-	double      log_top = log(r);
+	double      log_top = log((double) r);
 #endif
 
 	t = c;
@@ -408,7 +408,7 @@ reps(complex c, double p, int r, Bool binary, interior_t interior, double demran
 		    rep = (r + rep / 2) % r; /* binary decomp */
 #ifdef USE_LOG
 		if ( rep > 0 )
-		    rep = r * log(rep)/log_top; /* Log Scale */
+		    rep = (int) (r * log((double) rep)/log_top); /* Log Scale */
 #endif
 		return rep;
 	} else if (interior == LYAPUNOV) {
@@ -416,7 +416,7 @@ reps(complex c, double p, int r, Bool binary, interior_t interior, double demran
 	} else if (interior == INDEX) {
 		return 1 + index;
 	} else if (interior == ALPHA) {
-		return r * sqrt(alpha2);
+		return (int) (r * sqrt(alpha2));
 	} else
 		return r;
 }
@@ -514,8 +514,8 @@ free_mandelbrot(Display *display, mandelstruct *mp)
 			if (mp->ncolors && !mp->no_colors)
 				free_colors(display, mp->cmap, mp->colors,
 					mp->ncolors);
-				free(mp->colors);
-				mp->colors = (XColor *) NULL;
+			free(mp->colors);
+			mp->colors = (XColor *) NULL;
 		}
 		if (mp->cmap != None) {
 			XFreeColormap(display, mp->cmap);
