@@ -86,24 +86,24 @@ enum Suits {spade, diamond, club, heart};
 #ifdef FR
 // Ace => As, Jack => Valet,
 // Queen = Reine (Dame), King = Roi, Joker = Joker
-static /*const*/ char *RankNames[] = {"", "A",
+static const char *RankNames[] = {"", "A",
 	"2", "3", "4", "5", "6", "7", "8", "9", "10",
 	"V", "D", "R"};
 #else
 #ifdef NL
 // Ace => Aas, Jack => Boer (Farmer),
 // Queen = Vrouw (Lady), King = Heer (Gentleman), Joker = Joker
-static /*const*/ char *RankNames[] = {"", "A",
+static const char *RankNames[] = {"", "A",
 	"2", "3", "4", "5", "6", "7", "8", "9", "10",
 	"B", "V", "H"};
 #else
 #ifdef RU
 // Some may be approximations to Cyrillic
-static /*const*/ char *RankNames[] = {"", "T",
+static const char *RankNames[] = {"", "T",
 	"2", "3", "4", "5", "6", "7", "8", "9", "10",
 	"B", "Q", "K"};
 #else
-static /*const*/ char *RankNames[] = {"", "A",
+static const char *RankNames[] = {"", "A",
 	"2", "3", "4", "5", "6", "7", "8", "9", "10",
 	"J", "Q", "K"};
 #endif
@@ -1304,24 +1304,24 @@ init_solitare(ModeInfo * mi)
 	Display    *display = MI_DISPLAY(mi);
 	XGCValues gcv;
 
-	 if (mode_font == None)
+	if (mode_font == None)
 		mode_font = getFont(display);
-	  if (mode_font != None) {
-			gcv.font = mode_font->fid;
-			/*XSetFont(display, MI_GC(mi), mode_font->fid);*/
-			gcv.graphics_exposures = False;
-			gcv.foreground = MI_WHITE_PIXEL(mi);
-			gcv.background = MI_BLACK_PIXEL(mi);
-			if ((mp->gc = XCreateGC(display, MI_WINDOW(mi),
-			  GCForeground | GCBackground | GCGraphicsExposures | GCFont,
-					&gcv)) == None) {
-				return;
-			}
-			mp->ascent = mode_font->ascent;
-			mp->height = font_height(mode_font);
-			for (i = 0; i < 256; i++)
-				char_width[i] = 8;
+	if (mode_font != None) {
+		gcv.font = mode_font->fid;
+		/*XSetFont(display, MI_GC(mi), mode_font->fid);*/
+		gcv.graphics_exposures = False;
+		gcv.foreground = MI_WHITE_PIXEL(mi);
+		gcv.background = MI_BLACK_PIXEL(mi);
+		if ((mp->gc = XCreateGC(display, MI_WINDOW(mi),
+		  GCForeground | GCBackground | GCGraphicsExposures | GCFont,
+				&gcv)) == None) {
+			return;
 		}
+		mp->ascent = mode_font->ascent;
+		mp->height = font_height(mode_font);
+		for (i = 0; i < 256; i++)
+			char_width[i] = 8;
+	}
 #endif
 	if (bp->game) {
 		if (bp->width != MI_WIDTH(mi) || bp->height != MI_HEIGHT(mi)) {
