@@ -33,6 +33,12 @@ static const char sccsid[] = "@(#)mode.c	5.12 04/03/09 xlockmore";
 
 LockStruct  LockProcs[] =
 {
+#ifdef MODE_anemone
+	{(char *) "anemone", init_anemone, draw_anemone, release_anemone,
+	 init_apollonian, init_anemone, (ModeHook *) NULL, &anemone_opts,
+	 50000, 1, 1, 1, 64, 1.0, (char *) "",
+	 (char *) "Shows wiggling tentacles", 0, NULL},
+#endif
 #ifdef MODE_ant
 	{(char *) "ant", init_ant, draw_ant, release_ant,
 	 refresh_ant, init_ant, (ModeHook *) NULL, &ant_opts,
@@ -49,7 +55,7 @@ LockStruct  LockProcs[] =
 	{(char *) "apollonian", init_apollonian, draw_apollonian, release_apollonian,
 	 init_apollonian, init_apollonian, (ModeHook *) NULL, &apollonian_opts,
 	 1000000, 64, 20, 1, 64, 1.0, (char *) "",
-	 (char *) "Shows Apollonian Circles", 0, NULL},
+	 (char *) "Shows Apollonian circles", 0, NULL},
 #endif
 #ifdef MODE_atlantis
 	{(char *) "atlantis", init_atlantis, draw_atlantis, release_atlantis,
@@ -114,7 +120,7 @@ LockStruct  LockProcs[] =
 #ifdef MODE_bubble
 	{(char *) "bubble", init_bubble, draw_bubble, release_bubble,
 	 refresh_bubble, init_bubble, (ModeHook *) NULL, &bubble_opts,
-	 100000, 25, 1, 100, 64, 0.6, (char *) "",
+	 100000, 25, 1, 100, 64, 0.3, (char *) "",
 	 (char *) "Shows popping bubbles", 0, NULL},
 #endif
 #ifdef MODE_bubble3d
@@ -183,6 +189,12 @@ LockStruct  LockProcs[] =
 	 1000000, -30, 2, -10, 64, 0.6, (char *) "",
 	 (char *) "Shows art as ugly as sin", 0, NULL},
 #endif
+#ifdef MODE_deluxe
+	{(char *) "deluxe", init_deluxe, draw_deluxe, release_deluxe,
+	 refresh_deluxe, init_deluxe, (ModeHook *) NULL, &deluxe_opts,
+	 5000, 5, 1, 1, 64, 1.0, (char *) "",
+	 (char *) "Shows pulsing sequence of stars, circles, and lines", 0, NULL},
+#endif
 #ifdef MODE_demon
 	{(char *) "demon", init_demon, draw_demon, release_demon,
 	 refresh_demon, init_demon, (ModeHook *) NULL, &demon_opts,
@@ -554,12 +566,24 @@ LockStruct  LockProcs[] =
 	 15000, 100, 1, -3, 64, 1.0, (char *) "",
 	 (char *) "Shows fireworks", 0, NULL},
 #endif
+#ifdef MODE_pyro2
+	{(char *) "pyro2", init_pyro2, draw_pyro2, release_pyro2,
+	refresh_pyro2, init_pyro2, (ModeHook *) NULL, &pyro2_opts,
+	15000, 100, 1, -3, 64, 1.0, (char *) "",
+	(char *) "Shows other fireworks", 0, NULL},
+#endif
 #ifdef MODE_qix
 	{(char *) "qix", init_qix, draw_qix, release_qix,
 	 refresh_qix, init_qix, (ModeHook *) NULL, &qix_opts,
 	 30000, -5, 32, 1, 64, 1.0, (char *) "",
 	 (char *) "Shows spinning lines a la Qix(tm)", 0, NULL},
 #endif
+#ifdef MODE_rain
+	{(char *) "rain", init_rain, draw_rain, release_rain,
+	 refresh_rain, init_rain, (ModeHook *) NULL, &rain_opts,
+	 35000, 1, 1, 1, 64, 0.3, (char *) "",
+	 (char *) "It's raining", 0, NULL},
+#endif
 #ifdef MODE_roll
 	{(char *) "roll", init_roll, draw_roll, release_roll,
 	 refresh_roll, init_roll, (ModeHook *) NULL, &roll_opts,
@@ -937,7 +961,7 @@ ExpandPath(char *path)
 						path++;
 						break;
 				}
-
+				break;
 			default:
 				*ep++ = *path++;
 				break;
