@@ -637,7 +637,9 @@ extern void release_last_mode(ModeInfo *);
 #define MODE_puzzle
 #endif /* !WIN32 */
 #define MODE_pyro
+#define MODE_pyro2
 #define MODE_qix
+#define MODE_rain
 #define MODE_roll
 #define MODE_rotor
 #define MODE_scooter /* should be combined with star some day */
@@ -721,7 +723,9 @@ extern void release_last_mode(ModeInfo *);
 #define MODE_petal
 #define MODE_puzzle
 #define MODE_pyro
+#define MODE_pyro2
 #define MODE_qix
+#define MODE_rain
 #define MODE_roll
 #define MODE_space /* should be combined with star some day */
 #define MODE_sphere
@@ -1465,6 +1469,14 @@ extern ModeHook refresh_pyro;
 extern ModeSpecOpt pyro_opts;
 #endif
 
+#ifdef MODE_pyro2
+extern ModeHook init_pyro2;
+extern ModeHook draw_pyro2;
+extern ModeHook release_pyro2;
+extern ModeHook refresh_pyro2;
+extern ModeSpecOpt pyro2_opts;
+#endif
+
 #ifdef MODE_qix
 extern ModeHook init_qix;
 extern ModeHook draw_qix;
@@ -1473,6 +1485,14 @@ extern ModeHook refresh_qix;
 extern ModeSpecOpt qix_opts;
 #endif
 
+#ifdef MODE_rain
+extern ModeHook init_rain;
+extern ModeHook draw_rain;
+extern ModeHook release_rain;
+extern ModeHook refresh_rain;
+extern ModeSpecOpt rain_opts;
+#endif
+
 #ifdef MODE_roll
 extern ModeHook init_roll;
 extern ModeHook draw_roll;
