@@ -8,6 +8,7 @@ typedef struct LockStruct_s
 
 static LockStruct LockProcs[] =
 {
+{(char *) "anemone", (char *) "Shows wiggling tentacles"},
 {(char *) "ant", (char *) "Shows Langton's and Turk's generalized ants"},
 {(char *) "ant3d", (char *) "Shows 3D ants"},
 {(char *) "apollonian", (char *) "Shows Apollonian Circles"},
@@ -121,7 +122,9 @@ static LockStruct LockProcs[] =
 {(char *) "polyominoes", (char *) "Shows attempts to place polyominoes into a rectangle"},
 {(char *) "puzzle", (char *) "Shows a puzzle being scrambled and then solved"},
 {(char *) "pyro", (char *) "Shows fireworks"},
+{(char *) "pyro2", (char *) "Shows other fireworks"},
 {(char *) "qix", (char *) "Shows spinning lines a la Qix(tm)"},
+{(char *) "rain", (char *) "Shows rain"},
 {(char *) "roll", (char *) "Shows a rolling ball"},
 {(char *) "rotor", (char *) "Shows Tom's Roto-Rooter"},
 #ifdef USE_GL
